@@ -71,29 +71,20 @@ class ViewController extends Controller {
 	 * @return TemplateResponse
 	 */
 	public function index() {
-		$runningOn = $this->config->getSystemValue('version');
-		$runningOnNextcloud10OrLater = version_compare($runningOn, '9.1', '>=');
-		$runningOnNextcloud11OrLater = version_compare($runningOn, '11', '>=');
-
-		$supportsClass = $runningOnNextcloud10OrLater;
-		$assetPipelineBroken = !$runningOnNextcloud10OrLater;
-		$needsAutosize = !$runningOnNextcloud11OrLater;
-
-		$isAssetPipelineEnabled = $this->config->getSystemValue('asset-pipeline.enabled', false);
-		if ($isAssetPipelineEnabled && $assetPipelineBroken) {
+		if ($this->needsAssetPipelineWarning()) {
 			return new TemplateResponse('calendar', 'main-asset-pipeline-unsupported');
 		}
 
+		$templateParameters = $this->getTemplateParams();
+
 		$user = $this->userSession->getUser();
 		$userId = $user->getUID();
 		$emailAddress = $user->getEMailAddress();
 
-		$appVersion = $this->config->getAppValue($this->appName, 'installed_version');
 		$initialView = $this->config->getUserValue($userId, $this->appName, 'currentView', null);
 		$skipPopover = $this->config->getUserValue($userId, $this->appName, 'skipPopover', 'no');
 		$weekNumbers = $this->config->getUserValue($userId, $this->appName, 'showWeekNr', 'no');
 		$firstRun = $this->config->getUserValue($userId, $this->appName, 'firstRun', null);
-		$defaultColor = $this->config->getAppValue('theming', 'color', '#0082C9');
 
 		// the default view will be saved as soon as a user
 		// opens the calendar app, therefore this is a good
@@ -110,64 +101,60 @@ class ViewController extends Controller {
 		if ($initialView === null) {
 			$initialView = 'month';
 		}
-		
-		$webCalWorkaround = $runningOnNextcloud10OrLater ? 'no' : 'yes';
-		$isIE = $this->request->isUserAgent([Request::USER_AGENT_IE]);
 
-		return new TemplateResponse('calendar', 'main', [
-			'appVersion' => $appVersion,
+		return new TemplateResponse('calendar', 'main', array_merge($templateParameters, [
 			'initialView' => $initialView,
 			'emailAddress' => $emailAddress,
 			'skipPopover' => $skipPopover,
 			'weekNumbers' => $weekNumbers,
 			'firstRun' => $firstRun,
-			'supportsClass' => $supportsClass,
-			'defaultColor' => $defaultColor,
-			'webCalWorkaround' => $webCalWorkaround,
 			'isPublic' => false,
-			'isIE' => $isIE,
-			'needsAutosize' => $needsAutosize,
-		]);
+			'isEmbedded' => false,
+			'token' => '',
+		]));
 	}
 
 	/**
 	 * @PublicPage
 	 * @NoCSRFRequired
 	 *
+	 * @param string $token
+	 *
 	 * @return TemplateResponse
 	 */
-	public function publicIndex() {
-		$runningOn = $this->config->getSystemValue('version');
-		$runningOnServer91OrLater = version_compare($runningOn, '9.1', '>=');
-		$runningOnNextcloud11OrLater = version_compare($runningOn, '11', '>=');
-
-		$supportsClass = $runningOnServer91OrLater;
-		$assetPipelineBroken = !$runningOnServer91OrLater;
-		$needsAutosize = !$runningOnNextcloud11OrLater;
-
-		$isAssetPipelineEnabled = $this->config->getSystemValue('asset-pipeline.enabled', false);
-		if ($isAssetPipelineEnabled && $assetPipelineBroken) {
+	public function publicIndexWithBranding($token) {
+		if ($this->needsAssetPipelineWarning()) {
 			return new TemplateResponse('calendar', 'main-asset-pipeline-unsupported');
 		}
 
-		$appVersion = $this->config->getAppValue($this->appName, 'installed_version');
-		$isIE = $this->request->isUserAgent([Request::USER_AGENT_IE]);
+		$templateParameters = $this->getTemplateParams();
+		$publicTemplateParameters = $this->getPublicTemplateParameters($token);
+		$params = array_merge($templateParameters, $publicTemplateParameters);
+		$params['isEmbedded'] = false;
+
+		return new TemplateResponse('calendar', 'public', $params, 'base');
+	}
+
+	/**
+	 * @PublicPage
+	 * @NoCSRFRequired
+	 *
+	 * @param string $token
+	 *
+	 * @return TemplateResponse
+	 */
+	public function publicIndexForEmbedding($token) {
+		if ($this->needsAssetPipelineWarning()) {
+			return new TemplateResponse('calendar', 'main-asset-pipeline-unsupported');
+		}
+
+		$templateParameters = $this->getTemplateParams();
+		$publicTemplateParameters = $this->getPublicTemplateParameters($token);
+		$params = array_merge($templateParameters, $publicTemplateParameters);
+		$params['isEmbedded'] = true;
+
+		$response = new TemplateResponse('calendar', 'main', $params, 'public');
 
-		$response = new TemplateResponse('calendar', 'main', [
-			'appVersion' => $appVersion,
-			'initialView' => 'month',
-			'emailAddress' => '',
-			'skipPopover' => 'no',
-			'weekNumbers' => 'no',
-			'supportsClass' => $supportsClass,
-			'firstRun' => 'no',
-			'isIE' => $isIE,
-			'webCalWorkaround' => 'no',
-			'isPublic' => true,
-			'shareURL' => $this->request->getServerProtocol() . '://' . $this->request->getServerHost() . $this->request->getRequestUri(),
-			'previewImage' => $this->urlGenerator->getAbsoluteURL($this->urlGenerator->imagePath('core', 'favicon-touch.png')),
-			'needsAutosize' => $needsAutosize,
-		], 'public');
 		$response->addHeader('X-Frame-Options', 'ALLOW');
 		$csp = new ContentSecurityPolicy();
 		$csp->addAllowedScriptDomain('*');
@@ -175,4 +162,97 @@ class ViewController extends Controller {
 
 		return $response;
 	}
+
+	/**
+	 * @PublicPage
+	 * @NoCSRFRequired
+	 *
+	 * @param string $token
+	 *
+	 * @return TemplateResponse
+	 */
+	public function publicIndexForEmbeddingLegacy($token) {
+		return $this->publicIndexForEmbedding($token);
+	}
+
+	/**
+	 * get common parameters used for all three routes
+	 * @return array
+	 */
+	private function getTemplateParams() {
+		$runningOn = $this->config->getSystemValue('version');
+		$runningOnNextcloud10OrLater = version_compare($runningOn, '9.1', '>=');
+		$runningOnNextcloud11OrLater = version_compare($runningOn, '11', '>=');
+		$runningOnNextcloud12OrLater = version_compare($runningOn, '12', '>=');
+
+		$supportsClass = $runningOnNextcloud10OrLater;
+		$needsAutosize = !$runningOnNextcloud11OrLater;
+		$shareeCanEditShares = !$runningOnNextcloud12OrLater;
+		$shareeCanEditCalendarProperties = $runningOnNextcloud12OrLater;
+
+		$appVersion = $this->config->getAppValue($this->appName, 'installed_version');
+		$webCalWorkaround = $runningOnNextcloud10OrLater ? 'no' : 'yes';
+		$isIE = $this->request->isUserAgent([Request::USER_AGENT_IE]);
+		$defaultColor = $this->config->getAppValue('theming', 'color', '#0082C9');
+
+		return [
+			'appVersion' => $appVersion,
+			'supportsClass' => $supportsClass,
+			'isIE' => $isIE,
+			'webCalWorkaround' => $webCalWorkaround,
+			'needsAutosize' => $needsAutosize,
+			'defaultColor' => $defaultColor,
+			'shareeCanEditShares' => $shareeCanEditShares ? 'yes' : 'no',
+			'shareeCanEditCalendarProperties' => $shareeCanEditCalendarProperties ? 'yes' : 'no',
+		];
+	}
+
+	/**
+	 * get common parameters for public sites
+	 * @param string $token
+	 * @return array
+	 */
+	private function getPublicTemplateParameters($token) {
+		$shareURL = $this->request->getServerProtocol() . '://';
+		$shareURL .= $this->request->getServerHost();
+		$shareURL .= $this->request->getRequestUri();
+
+		$relativeImagePath = $this->urlGenerator->imagePath('core', 'favicon-touch.png');
+		$previewImage = $this->urlGenerator->getAbsoluteURL($relativeImagePath);
+
+		$remoteBase = $this->urlGenerator->linkTo('', 'remote.php');
+		$remoteBase .= '/dav/public-calendars/' . $token . '?export';
+
+		$downloadUrl = $this->urlGenerator->getAbsoluteURL($remoteBase);
+
+		$protocolLength = strlen($this->request->getServerProtocol()) + 3;
+		$webcalUrl = 'webcal://' . substr($downloadUrl, $protocolLength);
+
+		return [
+			'initialView' => 'month',
+			'emailAddress' => '',
+			'skipPopover' => 'no',
+			'weekNumbers' => 'no',
+			'firstRun' => 'no',
+			'webCalWorkaround' => 'no',
+			'isPublic' => true,
+			'shareURL' => $shareURL,
+			'previewImage' => $previewImage,
+			'webcalURL' => $webcalUrl,
+			'downloadURL' => $downloadUrl,
+			'token' => $token,
+		];
+	}
+
+	/**
+	 * check if we need to show the asset pipeline warning
+	 * @return bool
+	 */
+	private function needsAssetPipelineWarning() {
+		$runningOn = $this->config->getSystemValue('version');
+		$assetPipelineBroken = version_compare($runningOn, '9.1', '<');
+		$isAssetPipelineEnabled = $this->config->getSystemValue('asset-pipeline.enabled', false);
+
+		return ($isAssetPipelineEnabled && $assetPipelineBroken);
+	}
 }
