@@ -2,6 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Calendariu",
+    "%s has published the calendar \"%s\"" : "%s espublizó'l calendariu «%s»",
+    "Too many redirects. Aborting ..." : "Milenta redireiciones. Albortando...",
+    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "El sirvidor remotu nun mos dio accesu al calendariu (fallu HTTP {%s})",
+    "Error connecting to remote server" : "Fallu coneutando col sirvidor remotu",
+    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fallu solicitando'l recursu nel sirvidor remotu. Esto quiciabes tea venceyao o un desaxuste de certificaos",
+    "Error requesting resource on remote server" : "Fallu solicitando'l recursu nel sirvidor remotu",
     "Individual" : "Individual",
     "Group" : "Grupu",
     "Resource" : "Recursu",
@@ -10,10 +16,16 @@ OC.L10N.register(
     "Required" : "Riquíu",
     "Optional" : "Opcional",
     "Does not attend" : "Nun atiendi",
+    "{name} ({email})" : "{name} ({email})",
     "You are in an unknown timezone ({tz}), falling back to UTC" : "Tas nunca zona horaria desconocia  ({tz}), torna a UTC",
     "Please create a calendar first." : "Por favor, crea entantes un calendariu.",
-    "New event" : "Nuevu eventu",
+    "New event" : "Eventu nuevu",
+    "Error saving WebCal-calendar" : "Fallu guardando'l calendariu WebCal",
+    "WebDAV address for subscriptions" : "Direición WebDAV pa soscripciones",
+    "EMail has been sent." : "Unvióse'l corréu.",
+    "There was an issue while sending your EMail." : "Hebo un problema entrín s'unviaba'l to corréu.",
     "group" : "grupu",
+    "Details" : "Detalles",
     "Attendees" : "Asistentes",
     "Reminders" : "Recordatorios",
     "Repeating" : "Repetición",
@@ -27,7 +39,7 @@ OC.L10N.register(
     "Please select a calendar!" : "¡Por favor, esbilla un calendariu!",
     "Global" : "Global",
     "None" : "Dengún",
-    "Every day" : "Acaldía",
+    "Every day" : "Caldía",
     "Every week" : "Cada selmana",
     "Every month" : "Cada mes",
     "Every year" : "Cada añu",
@@ -69,8 +81,6 @@ OC.L10N.register(
     "{type} at {time}" : "{type} a {time}",
     "{calendar} shared by {owner}" : "{calendar} compartíu por  {owner}",
     "Title of the Event" : "Títulu del eventu",
-    "starts" : "entama",
-    "ends" : "fina",
     "All day Event" : "Tol día",
     "Delete" : "Desaniciar",
     "Cancel" : "Encaboxar",
@@ -83,6 +93,8 @@ OC.L10N.register(
     "Event status" : "Estáu del eventu",
     "Visibility when sharing" : "Visibilida mientres compartes",
     "Export" : "Esportar",
+    "Hello," : "Hola,",
+    "Cheers!" : "¡Salú!",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Por cuenta d'un bug d'upstream, el calendariu nun soporta la carauterística d'asset pipeline",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Contauta col to alministrador y pídi-y que desactive la opción de configuración \"asset-pipeline.enabled\".",
     "Day" : "Día",
@@ -95,12 +107,17 @@ OC.L10N.register(
     "More" : "Más",
     "Edit" : "Editar",
     "Link" : "Enllaz",
+    "iCal link" : "Enllaz iCal",
     "Download" : "Baxar",
     "Share with users or groups" : "Compartir con usuarios o grupos",
     "can edit" : "pue editar",
+    "Public access" : "Accesu públicu",
+    "Send" : "Unviar",
     "New Calendar" : "Calendariu nuevu",
     "Name" : "Nome",
     "New Subscription" : "Nueva Soscripción",
+    "Go back" : "Dir p'atrás",
+    "Calendar does not exist" : "El calendariu nun esiste",
     "Edit event" : "Editar eventu",
     "Delete Event" : "Desaniciar Eventu",
     "Save Event" : "Guardar Eventu",
@@ -126,11 +143,16 @@ OC.L10N.register(
     "Analyzing calendar" : "Analizando calendariu",
     "The file contains objects incompatible with the selected calendar" : "El ficheru contién oxetos incompatibles col calendariu esbilláu",
     "New calendar" : "Calendariu nuevu",
+    "File is empty" : "El ficheru ta baleru",
     "Import scheduled" : "Importar horariu",
+    "%s shared the calendar <strong>%s</strong> with you" : "%s compartió'l calendariu <strong>%s</strong> contigo",
+    "Publish URL" : "Espublizar URL",
     "Skip simple event editor" : "Saltar editor d'eventos simples",
+    "Show week numbers" : "Amosar númberos de la selmana",
     "Import calendar" : "Importar calendariu",
     "No Calendars selected for import" : "Nun s'esbilló nengún calendariu pa la importación",
     "Primary CalDAV address" : "Direición de calendariu CalDAV primariu",
-    "iOS/OS X CalDAV address" : "Direición de calendariu CalDAV iOS/OSX"
+    "iOS/OS X CalDAV address" : "Direición de calendariu CalDAV iOS/OSX",
+    "Subscribe" : "Soscribise"
 },
 "nplurals=2; plural=(n != 1);");
