@@ -38,6 +38,7 @@ OC.L10N.register(
     "Cancelled" : "Abgesagt",
     "Please add a title!" : "Bitte einen Titel hinzufügen!",
     "Please select a calendar!" : "Bitte einen Kalender auswählen!",
+    "The event ends before it starts!" : "Das Ereignis endet bevor es startet!",
     "Global" : "Global",
     "None" : "Keine",
     "Every day" : "jeden Tag",
@@ -85,8 +86,8 @@ OC.L10N.register(
     "Please enter a valid WebCal-URL" : "Bitte eine gültige WebCal-Adresse angeben",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Schwerer Fehler im webcal-Proxy. Bitte kontaktiere deinen Administrator für weitere Informationen.",
     "Title of the Event" : "Titel des Ereignisses",
-    "starts" : "Beginn",
-    "ends" : "Ende",
+    "Starts" : "Beginnt",
+    "Ends" : "Endet",
     "All day Event" : "Ganztägiges Ereignis",
     "Delete" : "Löschen",
     "Cancel" : "Abbrechen",
@@ -131,6 +132,8 @@ OC.L10N.register(
     "New Subscription" : "Neues Abonnement",
     "Go back" : "Zurück",
     "Go forward" : "Weiter",
+    "Calendar does not exist" : "Kalender existiert nicht",
+    "Maybe you got a wrong link or the calendar was unshared?" : "Möglicherweise hast Du einen falschen Link erhalten oder die Freigabe des Kalenders wurde aufgehoben",
     "Edit event" : "Ereignis bearbeiten",
     "Delete Event" : "Ereignis löschen",
     "Save Event" : "Ereignis speichern",
@@ -158,15 +161,17 @@ OC.L10N.register(
     "New calendar" : "Neuer Kalender",
     "File is empty" : "Datei ist leer",
     "Import scheduled" : "Import geplant",
-    "Subscribe & embed" : "Abonnieren & Einbetten",
+    "%s shared the calendar <strong>%s</strong> with you" : "%s hat den Kalender  <strong>%s</strong> mit Dir geteilt",
+    "Embed" : "Einbetten",
+    "IFrame to integrate" : "Iframe zum Einbinden",
     "Publish URL" : "URL veröffentlichen",
-    "Iframe to integrate" : "Iframe zum Einbinden",
     "Settings & import" : "Einstellungen & Import",
     "Skip simple event editor" : "Einfachen Ereignis-Editor überspringen",
     "Show week numbers" : "Kalenderwochen anzeigen",
     "Import calendar" : "Kalender importieren",
     "No Calendars selected for import" : "Keine Kalender für den Import ausgewählt",
     "Primary CalDAV address" : "Primäre CalDAV-Adresse",
-    "iOS/OS X CalDAV address" : "iOS-/OS-X-CalDAV-Adresse"
+    "iOS/OS X CalDAV address" : "iOS-/OS-X-CalDAV-Adresse",
+    "Subscribe" : "Abonnieren"
 },
 "nplurals=2; plural=(n != 1);");
