@@ -38,6 +38,7 @@ OC.L10N.register(
     "Cancelled" : "Abgebrochen",
     "Please add a title!" : "Bitte fügen Sie einen Titel hinzu!",
     "Please select a calendar!" : "Bitte wählen Sie einen Kalender aus!",
+    "The event ends before it starts!" : "Das Ereignis endet bevor es startet!",
     "Global" : "Global",
     "None" : "Keine",
     "Every day" : "Jeden Tag",
@@ -85,8 +86,8 @@ OC.L10N.register(
     "Please enter a valid WebCal-URL" : "Bitte geben Sie eine gültige WebCal-URL an",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Schwerer Fehler im webcal-Proxy. Bitte kontaktieren Sie Ihren Administrator für weitere Informationen.",
     "Title of the Event" : "Titel der Veranstaltung",
-    "starts" : "Beginnt",
-    "ends" : "endet",
+    "Starts" : "Beginnt",
+    "Ends" : "Endet",
     "All day Event" : "Ganztägige Veranstaltung",
     "Delete" : "Löschen",
     "Cancel" : "Abbrechen",
@@ -131,6 +132,8 @@ OC.L10N.register(
     "New Subscription" : "neues Abonnement",
     "Go back" : "Zurück gehen",
     "Go forward" : "Weiter gehen",
+    "Calendar does not exist" : "Kalender existiert nicht",
+    "Maybe you got a wrong link or the calendar was unshared?" : "Möglicherweise haben Sie einen falschen Link erhalten oder die Freigabe des Kalenders wurde aufgehoben",
     "Edit event" : "Termin bearbeiten",
     "Delete Event" : "Termin löschen",
     "Save Event" : "Termin speichern",
@@ -158,15 +161,17 @@ OC.L10N.register(
     "New calendar" : "Neuer Kalender",
     "File is empty" : "Datei ist leer",
     "Import scheduled" : "Import geplant",
-    "Subscribe & embed" : "Abonnieren & einbetten",
+    "%s shared the calendar <strong>%s</strong> with you" : "%s hat den Kalender <strong>%s</strong> mit Dir geteilt",
+    "Embed" : "Einbetten",
+    "IFrame to integrate" : "Iframe zum Einbinden",
     "Publish URL" : "URL veröffentlichen",
-    "Iframe to integrate" : "Iframe zum Einbinden",
     "Settings & import" : "Einstellungen & Import",
     "Skip simple event editor" : "Einfachen Termin-Editor überspringen",
     "Show week numbers" : "Kalenderwochen anzeigen",
     "Import calendar" : "Kalender importieren",
     "No Calendars selected for import" : "Es wurde kein Kalender für den Import ausgewählt",
     "Primary CalDAV address" : "Primäre CalDAV-Adresse",
-    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-Adresse"
+    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-Adresse",
+    "Subscribe" : "Abonnieren"
 },
 "nplurals=2; plural=(n != 1);");
