@@ -38,6 +38,7 @@ OC.L10N.register(
     "Cancelled" : "Cancelado",
     "Please add a title!" : "¡Por favor añade un título!",
     "Please select a calendar!" : "¡Por favor selecciona un calendario!",
+    "The event ends before it starts!" : "¡El evento termina antes de que incie!",
     "Global" : "Global",
     "None" : "Ninguno",
     "Every day" : "Cada día",
@@ -85,8 +86,8 @@ OC.L10N.register(
     "Please enter a valid WebCal-URL" : "Por favor introduzca una URL valida WebCal",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Error grave en el proxy webcal. Por favor, póngase en contacto con el administrador para más información.",
     "Title of the Event" : "Título del evento",
-    "starts" : "comienza",
-    "ends" : "finaliza",
+    "Starts" : "Comienza",
+    "Ends" : "Finaliza",
     "All day Event" : "Todo el día",
     "Delete" : "Eliminar",
     "Cancel" : "Cancelar",
@@ -131,6 +132,8 @@ OC.L10N.register(
     "New Subscription" : "Nueva suscripción",
     "Go back" : "Atrás",
     "Go forward" : "Adelante",
+    "Calendar does not exist" : "El calendario no existe",
+    "Maybe you got a wrong link or the calendar was unshared?" : "¿Quizás el enlace está equivocado o el calendario dejó de ser compartido?",
     "Edit event" : "Editar evento",
     "Delete Event" : "Eliminar evento",
     "Save Event" : "Guardar evento",
@@ -158,15 +161,17 @@ OC.L10N.register(
     "New calendar" : "Nuevo calendario",
     "File is empty" : "El archivo está vacío",
     "Import scheduled" : "Importar horario",
-    "Subscribe & embed" : "Suscribir e incrustar",
+    "%s shared the calendar <strong>%s</strong> with you" : "%s compartió el calendario <strong>%s</strong> contigo",
+    "Embed" : "Insertar",
+    "IFrame to integrate" : "IFrame para insertar",
     "Publish URL" : "Publicar URL",
-    "Iframe to integrate" : "Iframe para integrar",
     "Settings & import" : "Ajustes & importar",
     "Skip simple event editor" : "Omitir el editor de evento único",
     "Show week numbers" : "Mostrar numero de semana",
     "Import calendar" : "Importar calendario",
     "No Calendars selected for import" : "No se seleccionó un calendario para importar",
     "Primary CalDAV address" : "Direccion de calendario CalDAV primario",
-    "iOS/OS X CalDAV address" : "Direccion de calendario CalDAV iOS/OSX"
+    "iOS/OS X CalDAV address" : "Direccion de calendario CalDAV iOS/OSX",
+    "Subscribe" : "Suscribirse"
 },
 "nplurals=2; plural=(n != 1);");
