@@ -12,6 +12,7 @@ OC.L10N.register(
     "Does not attend" : "Ei võta soa",
     "Please create a calendar first." : "Palun loo esmalt kalender.",
     "New event" : "Uus sündmus",
+    "group" : "grupp",
     "Attendees" : "Osalejad",
     "Reminders" : "Meelespead",
     "Repeating" : "Kordamine",
@@ -59,8 +60,6 @@ OC.L10N.register(
     "{type} at {time}" : "{type} kell {time}",
     "{calendar} shared by {owner}" : "{calendar} jagas {owner}",
     "Title of the Event" : "Sündmuse pealkiri",
-    "starts" : "algab",
-    "ends" : "lõpeb",
     "All day Event" : "Kogu päeva sündmus",
     "Delete" : "Kustuta",
     "Cancel" : "Loobu",
@@ -82,7 +81,6 @@ OC.L10N.register(
     "Link" : "Link",
     "Download" : "Lae alla",
     "can edit" : "saab muuta",
-    "group" : "grupp",
     "New Calendar" : "Uus kalender",
     "Name" : "Nimi",
     "New Subscription" : "Uus tellimus",
@@ -107,7 +105,6 @@ OC.L10N.register(
     "Analyzing calendar" : "Kalendri analüüsimine",
     "New calendar" : "Uus kalender",
     "Import scheduled" : "Importimine on ajastatud",
-    "Settings" : "Seaded",
     "Import calendar" : "Impordi kalender",
     "No Calendars selected for import" : "Pole valitud kalendreid, mida importida",
     "Primary CalDAV address" : "Primaarne CalDAV aadress",
