@@ -21,7 +21,7 @@ OC.L10N.register(
     "Please create a calendar first." : "Veuillez d'abord créer un calendrier.",
     "New event" : "Nouvel événement",
     "CalDAV address for clients" : "Adresse CalDAV pour les clients",
-    "Error saving WebCal-calendar" : "Erreur de sauvegarde du calendrier WebCal",
+    "Error saving WebCal-calendar" : "Erreur lors de la sauvegarde du calendrier WebCal",
     "WebDAV address for subscriptions" : "Adresse WebDAV pour s'inscrire",
     "EMail has been sent." : "L'EMail a été envoyé.",
     "There was an issue while sending your EMail." : "Il y a eu un problème lors de l'envoi de votre EMail.",
@@ -38,6 +38,7 @@ OC.L10N.register(
     "Cancelled" : "Annulé",
     "Please add a title!" : "Veuillez ajouter un titre !",
     "Please select a calendar!" : "Veuillez sélectionner un calendrier !",
+    "The event ends before it starts!" : "L'évènement se termine avant qu'il ne commence !",
     "Global" : "Global",
     "None" : "Aucun",
     "Every day" : "Chaque jour",
@@ -85,8 +86,8 @@ OC.L10N.register(
     "Please enter a valid WebCal-URL" : "Veuillez saisir une URL WebCal valide",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Erreur grave du mandataire webcal.  Communiquez avec votre administrateur de réseau pour plus de renseignements.",
     "Title of the Event" : "Titre de l'événement",
-    "starts" : "démarre",
-    "ends" : "termine",
+    "Starts" : "Commence",
+    "Ends" : "Termine",
     "All day Event" : "Journée entière",
     "Delete" : "Supprimer",
     "Cancel" : "Annuler",
@@ -111,7 +112,7 @@ OC.L10N.register(
     "Day" : "Jour",
     "Week" : "Semaine",
     "Month" : "Mois",
-    "Today" : "Aujourd'hui",
+    "Today" : "Auj.",
     "Some events in this calendar are broken. Please check the JS console for more info." : "Certains événements de cet agenda sont cassés. Merci de consulter la console JS pour plus d'info.",
     "Share Calendar" : "Partager l'agenda",
     "Shared" : "Partagé",
@@ -131,6 +132,8 @@ OC.L10N.register(
     "New Subscription" : "Nouvel abonnement",
     "Go back" : "Aller au précédent",
     "Go forward" : "Aller au suivant",
+    "Calendar does not exist" : "L'agenda n'existe pas",
+    "Maybe you got a wrong link or the calendar was unshared?" : "Vous avez peut-être obtenu un mauvais lien ou le partage de l'agenda a été annulé ?",
     "Edit event" : "Modifier l'événement",
     "Delete Event" : "Supprimer l'événement",
     "Save Event" : "Enregistrer l'événement",
@@ -158,15 +161,17 @@ OC.L10N.register(
     "New calendar" : "Nouvel agenda",
     "File is empty" : "Le fichier est vide",
     "Import scheduled" : "Importation planifiée",
-    "Subscribe & embed" : "Abonnement & intégration",
+    "%s shared the calendar <strong>%s</strong> with you" : "%s a partagé l'agenda <strong>%s</strong> avec vous",
+    "Embed" : "Embarquer",
+    "IFrame to integrate" : "IFrame à intégrer",
     "Publish URL" : "Publier l'URL",
-    "Iframe to integrate" : "Iframe à intégrer",
     "Settings & import" : "Paramètres & Importation",
     "Skip simple event editor" : "Passer l'éditeur d'évènement simple",
     "Show week numbers" : "Afficher les numéros de semaine",
     "Import calendar" : "Importer un agenda",
     "No Calendars selected for import" : "Aucun agenda sélectionné pour import",
     "Primary CalDAV address" : "Adresse CalDAV principale",
-    "iOS/OS X CalDAV address" : "Adresse CalDAV pour iOS/OS X"
+    "iOS/OS X CalDAV address" : "Adresse CalDAV pour iOS/OS X",
+    "Subscribe" : "S'abonner"
 },
 "nplurals=2; plural=(n > 1);");
