@@ -38,6 +38,7 @@ OC.L10N.register(
     "Cancelled" : "Hætt við",
     "Please add a title!" : "Settu inn titil!",
     "Please select a calendar!" : "Veldu dagatal!",
+    "The event ends before it starts!" : "Atburðurinn endar áður en hann byrjar!",
     "Global" : "Almennt",
     "None" : "Ekkert",
     "Every day" : "Daglega",
@@ -85,8 +86,8 @@ OC.L10N.register(
     "Please enter a valid WebCal-URL" : "Skráðu inn gilda WebCal-slóð",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Alvarleg villa í webcal-milliþjóni. Hafðu samband við kerfisstjóra.",
     "Title of the Event" : "Titill atburðar",
-    "starts" : "byrjar",
-    "ends" : "endar",
+    "Starts" : "Byrjar",
+    "Ends" : "Endar",
     "All day Event" : "Heilsdagsviðburður",
     "Delete" : "Eyða",
     "Cancel" : "Hætta við",
@@ -131,6 +132,8 @@ OC.L10N.register(
     "New Subscription" : "Ný áskrift",
     "Go back" : "Fara til baka",
     "Go forward" : "Fara áfram",
+    "Calendar does not exist" : "Dagatalið er ekki til",
+    "Maybe you got a wrong link or the calendar was unshared?" : "Hugsanlega ertu með rangan tengil eða að deilingu var hætt á dagatalinu?",
     "Edit event" : "Breyta atburði",
     "Delete Event" : "Eyða atburði",
     "Save Event" : "Vista atburð",
@@ -158,15 +161,17 @@ OC.L10N.register(
     "New calendar" : "Nýtt dagatal",
     "File is empty" : "Skráin er tóm",
     "Import scheduled" : "Áætlaður innflutningur",
-    "Subscribe & embed" : "Gerast áskrifandi og ívefja",
+    "%s shared the calendar <strong>%s</strong> with you" : "%s deildi dagatalinu <strong>%s</strong> með þér",
+    "Embed" : "Ívefja",
+    "IFrame to integrate" : "Iframe-rammi til að samþætta",
     "Publish URL" : "Gefa út slóð",
-    "Iframe to integrate" : "Iframe-rammi til að samþætta",
     "Settings & import" : "Stillingar og innflutningur",
     "Skip simple event editor" : "Sleppa einföldum atburðaritli",
     "Show week numbers" : "Sýna vikunúmer",
     "Import calendar" : "Flytja inn dagatal",
     "No Calendars selected for import" : "Engin dagatöl valin til innflutnings",
     "Primary CalDAV address" : "Aðal-CalDAV-vistfang",
-    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-vistfang"
+    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-vistfang",
+    "Subscribe" : "Gerast áskrifandi"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
