@@ -38,6 +38,7 @@ OC.L10N.register(
     "Cancelled" : "キャンセル済",
     "Please add a title!" : "タイトルを追加してください！",
     "Please select a calendar!" : "カレンダーを選択してください！",
+    "The event ends before it starts!" : "イベントが開始前に終了します!",
     "Global" : "全般",
     "None" : "なし",
     "Every day" : "毎日",
@@ -85,8 +86,8 @@ OC.L10N.register(
     "Please enter a valid WebCal-URL" : "有効なWebCal-URLを入力してください",
     "Severe error in webcal proxy. Please contact administrator for more information." : "webcalプロキシの重大なエラーです。 詳細については、管理者にお問い合わせください。",
     "Title of the Event" : "イベントのタイトル",
-    "starts" : "開始",
-    "ends" : "終了",
+    "Starts" : "開始",
+    "Ends" : "終了",
     "All day Event" : "終日イベント",
     "Delete" : "削除",
     "Cancel" : "キャンセル",
@@ -158,9 +159,7 @@ OC.L10N.register(
     "New calendar" : "新しいカレンダー",
     "File is empty" : "ファイルが空です",
     "Import scheduled" : "スケジュールのインポート",
-    "Subscribe & embed" : "購読 と 埋め込み",
     "Publish URL" : "URLを公開する",
-    "Iframe to integrate" : "Iframeで統合する",
     "Settings & import" : "設定とインポート",
     "Skip simple event editor" : "シンプルイベントエディタをスキップ",
     "Show week numbers" : "週番号を表示する",
