@@ -38,6 +38,7 @@ OC.L10N.register(
     "Cancelled" : "Geannuleerd",
     "Please add a title!" : "Voeg een titel toe!",
     "Please select a calendar!" : "Selecteer een agenda!",
+    "The event ends before it starts!" : "De afspraak eindigt voor het begin!",
     "Global" : "Globaal",
     "None" : "Geen",
     "Every day" : "Iedere dag",
@@ -64,7 +65,7 @@ OC.L10N.register(
     "days" : "dagen",
     "week" : "week",
     "before" : "voor",
-    "start" : "start",
+    "start" : "begint",
     "end" : "einde",
     "Editing reminders of unknown type not supported." : "Bewerken van herinneringen van onbekende types wordt niet ondersteund.",
     "Week {number} of {year}" : "Week {number} van {year}",
@@ -85,8 +86,8 @@ OC.L10N.register(
     "Please enter a valid WebCal-URL" : "Voer een geldig WebCal-URL in",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Ernstige fout in webcal proxy. Neem contact op met de beheerder voor meer informatie.",
     "Title of the Event" : "Titel van de afspraak",
-    "starts" : "begint",
-    "ends" : "eindigt",
+    "Starts" : "Beginnen",
+    "Ends" : "Eindigt",
     "All day Event" : "Hele dag",
     "Delete" : "Verwijderen",
     "Cancel" : "Annuleren",
@@ -131,6 +132,8 @@ OC.L10N.register(
     "New Subscription" : "Nieuw abonnement",
     "Go back" : "Ga terug",
     "Go forward" : "Ga verder",
+    "Calendar does not exist" : "Agenda bestaat niet",
+    "Maybe you got a wrong link or the calendar was unshared?" : "Kreeg je een verkeerde link of wordt de agenda niet gedeeld?",
     "Edit event" : "Bewerk gebeurtenis",
     "Delete Event" : "Verwijder afspraak",
     "Save Event" : "Bewaar afspraak",
@@ -142,7 +145,7 @@ OC.L10N.register(
     "times every" : "keer elke",
     "Add" : "Toevoegen",
     "E-Mail address of attendee" : "E-mailadres van deelnemer",
-    "Please add your email address in the personal settings in order to add attendees." : "Stel uw e-mail adres in in de account instellingen om aanwezigen toe te voegen.",
+    "Please add your email address in the personal settings in order to add attendees." : "Stel je e-mailadres in in de accountinstellingen om aanwezigen toe te voegen.",
     "from" : "van",
     "to" : "naar",
     "This event's repeating rule is not supported yet." : "De herhaalregel van deze afspraak wordt nog niet ondersteund.",
@@ -158,15 +161,17 @@ OC.L10N.register(
     "New calendar" : "Nieuwe agenda",
     "File is empty" : "Bestand te leeg",
     "Import scheduled" : "Import ingepland",
-    "Subscribe & embed" : "Abonneren & inbedden",
+    "%s shared the calendar <strong>%s</strong> with you" : "%s deelde agenda <strong>%s</strong> met jou",
+    "Embed" : "Inbedden",
+    "IFrame to integrate" : "Iframe om te integreren",
     "Publish URL" : "Publiceren URL",
-    "Iframe to integrate" : "Iframe om te integreren",
     "Settings & import" : "Instellingen & importeren",
     "Skip simple event editor" : "Negeer simpele afsprakenbewerker",
     "Show week numbers" : "Tonen weeknummers",
     "Import calendar" : "Importeer agenda",
     "No Calendars selected for import" : "Geen agenda's voor import opgegeven",
     "Primary CalDAV address" : "Primair CalDAV adres",
-    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adres"
+    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adres",
+    "Subscribe" : "Abonneren"
 },
 "nplurals=2; plural=(n != 1);");
