@@ -38,6 +38,7 @@ OC.L10N.register(
     "Cancelled" : "Przerwano",
     "Please add a title!" : "Proszę dodać tytuł!",
     "Please select a calendar!" : "Proszę wybrać kalendarz!",
+    "The event ends before it starts!" : "Wydarzenie zakończyło się zanim zaczęło!",
     "Global" : "Ogólny",
     "None" : "Brak.",
     "Every day" : "Codziennie",
@@ -85,8 +86,8 @@ OC.L10N.register(
     "Please enter a valid WebCal-URL" : "Wprowadź prawidłowy URL WebCal",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Poważny błąd proxy w WebCal. Aby uzyskać więcej informacji prosimy o kontakt z administratorem.",
     "Title of the Event" : "Nazwa wydarzenia",
-    "starts" : "rozpoczyna się",
-    "ends" : "kończy się",
+    "Starts" : "Zaczyna się",
+    "Ends" : "Kończy się",
     "All day Event" : "Wydarzenie całodniowe",
     "Delete" : "Usuń",
     "Cancel" : "Anuluj",
@@ -131,6 +132,8 @@ OC.L10N.register(
     "New Subscription" : "Nowa subskrypcja",
     "Go back" : "Wróć",
     "Go forward" : "Naprzód",
+    "Calendar does not exist" : "Kalendarz nie istnieje",
+    "Maybe you got a wrong link or the calendar was unshared?" : "Być może link jest nieprawidłowy lub kalendarz przestał być współdzielony.",
     "Edit event" : "Edytuj zdarzenie",
     "Delete Event" : "Usuń zdarzenie",
     "Save Event" : "Zapisz zdarzenie",
@@ -158,15 +161,17 @@ OC.L10N.register(
     "New calendar" : "Nowy kalendarz",
     "File is empty" : "Plik jest pusty",
     "Import scheduled" : "Import został zaplanowany",
-    "Subscribe & embed" : "Zasubskrybuj i osadź",
+    "%s shared the calendar <strong>%s</strong> with you" : "%s udostępnił Tobie kalendarz <strong>%s</strong>",
+    "Embed" : "Osadź",
+    "IFrame to integrate" : "Integracja z iframe",
     "Publish URL" : "Publikowanie URL",
-    "Iframe to integrate" : "Zintegrować z ramką",
     "Settings & import" : "Ustawienia i import",
     "Skip simple event editor" : "Pomiń prosty edytor zdarzeń",
     "Show week numbers" : "Pokaż numery tygodni",
     "Import calendar" : "Importuj kalendarz",
     "No Calendars selected for import" : "Nie wybrano kalendarzy do importu",
     "Primary CalDAV address" : "Podstawowy adres CalDAV",
-    "iOS/OS X CalDAV address" : "Adres CalDAV dla iOS/OS X"
+    "iOS/OS X CalDAV address" : "Adres CalDAV dla iOS/OS X",
+    "Subscribe" : "Subskrybuj"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
