@@ -5,7 +5,7 @@ OC.L10N.register(
     "%s has published the calendar \"%s\"" : "%s publicou o calendário \"%s\"",
     "Too many redirects. Aborting ..." : "Muitos redirecionamentos. Abortando...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "O servidor remoto não nos deu acesso ao calendário (erro HTTP {%s})",
-    "Error connecting to remote server" : "Erro ao conectar ao servidor remoto",
+    "Error connecting to remote server" : "Erro ao conectar o servidor remoto",
     "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Erro ao solicitar recurso no servidor remoto. Isso poderia estar relacionado a uma incompatibilidade de certificado",
     "Error requesting resource on remote server" : "Erro ao solicitar recurso no servidor remoto",
     "Individual" : "Individual",
@@ -15,16 +15,16 @@ OC.L10N.register(
     "Unknown" : "Desconhecido",
     "Required" : "Requerido",
     "Optional" : "Opcional",
-    "Does not attend" : "Não comparecer",
+    "Does not attend" : "Não atende",
     "{name} ({email})" : "{name} ({email})",
-    "You are in an unknown timezone ({tz}), falling back to UTC" : "Você está em um fuso horário desconhecido ({tz}), caindo de volta para UTC",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Você está em um fuso horário desconhecido ({tz}), retornando para UTC",
     "Please create a calendar first." : "Por favor crie um calendário primeiro.",
     "New event" : "Novo evento",
-    "CalDAV address for clients" : "Endereço CalDAV para clients",
-    "Error saving WebCal-calendar" : "Erro salvando o WebCal-calendário",
+    "CalDAV address for clients" : "Endereço CalDAV para clientes",
+    "Error saving WebCal-calendar" : "Erro salvando o calendário WebCal",
     "WebDAV address for subscriptions" : "Endereço WebDAV para inscrições",
     "EMail has been sent." : "E-mail enviado",
-    "There was an issue while sending your EMail." : "Houve um erro ao enviar o E-mail",
+    "There was an issue while sending your EMail." : "Houve um erro ao enviar o e-mail",
     "group" : "grupo",
     "Details" : "Detalhes",
     "Attendees" : "Participantes",
@@ -37,7 +37,8 @@ OC.L10N.register(
     "Tentative" : "Tentativa",
     "Cancelled" : "Cancelado",
     "Please add a title!" : "Por favor adicione um título!",
-    "Please select a calendar!" : "Por favor selecione um calendário!",
+    "Please select a calendar!" : "Por favor, selecione um calendário",
+    "The event ends before it starts!" : "O evento termina antes de começar!",
     "Global" : "Global",
     "None" : "Nenhum",
     "Every day" : "Todos os dias",
@@ -55,9 +56,9 @@ OC.L10N.register(
     "1 hour before" : "1 hora antes",
     "2 hours before" : "2 horas antes",
     "Custom" : "Personalizadas",
-    "Audio" : "Audio",
-    "E Mail" : "E Mail",
-    "Pop up" : "Pop up",
+    "Audio" : "Áudio",
+    "E Mail" : "E-mail",
+    "Pop up" : "Pop-up",
     "sec" : "seg",
     "min" : "min",
     "hours" : "horas",
@@ -66,31 +67,31 @@ OC.L10N.register(
     "before" : "antes",
     "start" : "início",
     "end" : "fim",
-    "Editing reminders of unknown type not supported." : "Lembretes de edição de tipos desconhecidos não são suportados.",
+    "Editing reminders of unknown type not supported." : "Edição de lembretes de tipos desconhecidos não são suportados.",
     "Week {number} of {year}" : "Semana {number} de {year}",
-    "Successfully imported" : "Importada com sucesso",
+    "Successfully imported" : "Importada",
     "Partially imported, 1 failure" : "Parcialmente importada, 1 falha",
     "Partially imported, {n} failures" : "Parcialmente importada, {n} falha",
     "Audio alarm" : "Alarme sonoro",
     "Pop-up" : "Pop-up",
-    "E-Mail" : "E-Mail",
+    "E-Mail" : "E-mail",
     "{type} {time} before the event starts" : "{type} {time} antes do evento iniciar",
     "{type} {time} before the event ends" : "{type} {time} antes do evento terminar",
-    "{type} {time} after the event starts" : "{type} {time} depois dos eventos iniciarem",
-    "{type} {time} after the event ends" : "{type} {time} após o término do evento",
+    "{type} {time} after the event starts" : "{type} {time} após o evento iniciar",
+    "{type} {time} after the event ends" : "{type} {time} após o evento terminar",
     "{type} at the event's start" : "{type} no início do evento",
     "{type} at the event's end" : "{type} no final do evento",
     "{type} at {time}" : "{type} em {time}",
     "{calendar} shared by {owner}" : "{calendar} compartilhado por {owner}",
     "Please enter a valid WebCal-URL" : "Por favor entre uma URL válida para WEbCal",
-    "Severe error in webcal proxy. Please contact administrator for more information." : "Erro severo no proxy webcam. Favor contate o administrador para mais informações",
+    "Severe error in webcal proxy. Please contact administrator for more information." : "Erro severo no proxy WebCal. Por favor contacte o administrador para mais informações.",
     "Title of the Event" : "Título do evento",
-    "starts" : "Inícios",
-    "ends" : "Finais",
+    "Starts" : "Inicia em",
+    "Ends" : "Termina em",
     "All day Event" : "Evento todo o dia",
     "Delete" : "Excluir",
     "Cancel" : "Cancelar",
-    "More ..." : "Mais ...",
+    "More ..." : "Mais...",
     "Create" : "Criar",
     "Update" : "Atualizar",
     "Close" : "Fechar",
@@ -99,15 +100,15 @@ OC.L10N.register(
     "Event status" : "Status do evento",
     "Visibility when sharing" : "Visível quando compartilhando",
     "Export" : "Exportar",
-    "%s has published the calendar %s" : "%s foi publicado no calendário%s",
-    "Hello," : "Ola,",
-    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Gostaríamos de avisa-lo que %s publicou um calendário {boldstart}%s{boldend}",
+    "%s has published the calendar %s" : "%s publicou o calendário%s",
+    "Hello," : "Olá,",
+    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Gostaríamos de avisá-lo que %s publicou o calendário {boldstart}%s{boldend}",
     "Click here to access it" : "Clique aqui para acessar",
-    "Cheers!" : "Saúde!",
-    "We wanted to inform you that %s has published the calendar %s." : "Gostaríamos de avisa-lo que %s publicou um calendário %s.",
-    "Click on the link below to access it" : "Clique no link abaixo para acessar",
-    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Devido a um bug a montante, o calendário não é atualmente capaz de fornecer suporte para o recurso de pipeline ativo.",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor entre em contato com o administrador e pedir-lhes para desativar a opção de configuração \"asset-pipeline.enabled\".",
+    "Cheers!" : "Saudações!",
+    "We wanted to inform you that %s has published the calendar %s." : "Gostaríamos de avisá-lo que %s publicou o calendário %s.",
+    "Click on the link below to access it" : "Clique no link abaixo para acessá-lo",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Devido a um bug, no momento o calendário é incapaz de fornecer suporte para o recurso de pipeline ativo.",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor entre em contato com o administrador e solicite a desativação da opção de configuração \"asset-pipeline.enabled\".",
     "Day" : "Dia",
     "Week" : "Semana",
     "Month" : "Mês",
@@ -123,50 +124,54 @@ OC.L10N.register(
     "Share with users or groups" : "Compartilhar com usuários ou grupos",
     "can edit" : "pode editar",
     "Share link" : "Compartilhar link",
-    "Public access" : "Acesso publico",
-    "Email link to person" : "Link via E-mail para pessoa",
+    "Public access" : "Acesso público",
+    "Email link to person" : "Enviar link via e-mail para alguém",
     "Send" : "Enviar",
     "New Calendar" : "Novo Calendário",
     "Name" : "Nome",
     "New Subscription" : "Nova Subscrição",
     "Go back" : "Voltar",
     "Go forward" : "Avançar",
+    "Calendar does not exist" : "O calendário não existe",
+    "Maybe you got a wrong link or the calendar was unshared?" : "Será o link errado ou calendário descompartilhado?",
     "Edit event" : "Editar evento",
-    "Delete Event" : "Apagar Evento",
+    "Delete Event" : "Excluir Evento",
     "Save Event" : "Salvar Evento",
     "Time" : "Horário",
     "Type" : "Digite",
     "Relative" : "Relativo",
     "Absolute" : "Absoluto",
     "Repeat" : "Repetir",
-    "times every" : "vezes sempre",
+    "times every" : "vezes a cada",
     "Add" : "Adicionar",
-    "E-Mail address of attendee" : "Endereço de email do participante",
-    "Please add your email address in the personal settings in order to add attendees." : "Por favor, adicione seu endereço de email nas configurações pessoais, a fim de adicionar participantes.",
+    "E-Mail address of attendee" : "Endereço de e-mail do participante",
+    "Please add your email address in the personal settings in order to add attendees." : "Por favor, adicione seu endereço de e-mail nas configurações pessoais, a fim de adicionar participantes.",
     "from" : "de",
     "to" : "para",
-    "This event's repeating rule is not supported yet." : "Regra de repetição de evento ainda não é suportada.",
-    "Support for advanced rules will be added with subsequent updates." : "Suporte para regras avançadas serão adicionados com atualizações subsequentes.",
-    "Reset repeating rule" : "Reiniciar regra de repetição",
-    "Repeat every ..." : "Repetir a cada ...",
-    "end repeat ..." : "fim da repetição ...",
+    "This event's repeating rule is not supported yet." : "Esta regra de repetição de evento ainda não é suportada.",
+    "Support for advanced rules will be added with subsequent updates." : "Suporte para regras avançadas serão adicionados em futuras atualizações.",
+    "Reset repeating rule" : "Resetar a regra de repetição",
+    "Repeat every ..." : "Repetir a cada...",
+    "end repeat ..." : "fim da repetição...",
     "times" : "vezes",
     "Import Calendars" : "Importar Calendários",
     "Import canceled" : "Importação cancelada",
     "Analyzing calendar" : "Analisando calendário",
     "The file contains objects incompatible with the selected calendar" : "O arquivo contém objetos incompatíveis com o calendário selecionado",
     "New calendar" : "Novo calendário",
-    "File is empty" : "Arquivo em branco",
+    "File is empty" : "Arquivo vazio",
     "Import scheduled" : "Importar agendados",
-    "Subscribe & embed" : "Subscrever & incorporar",
+    "%s shared the calendar <strong>%s</strong> with you" : "%s compartilhou o calendário <strong>%s</strong> com você",
+    "Embed" : "Embutido",
+    "IFrame to integrate" : "IFrame a integrar",
     "Publish URL" : "Publicar URL",
-    "Iframe to integrate" : "frame para integrar",
     "Settings & import" : "Configurações & Importação",
     "Skip simple event editor" : "Pular editor de eventos simples",
     "Show week numbers" : "Mostrar o número das semanas",
     "Import calendar" : "Importar calendário",
     "No Calendars selected for import" : "Nenhum Calendário foi selecionado para importação",
     "Primary CalDAV address" : "Endereço CalDAV primário",
-    "iOS/OS X CalDAV address" : "Endereço iOS/OS X CalDAV "
+    "iOS/OS X CalDAV address" : "Endereço iOS/OS X CalDAV ",
+    "Subscribe" : "Inscrever-se"
 },
 "nplurals=2; plural=(n > 1);");
