@@ -38,6 +38,7 @@ OC.L10N.register(
     "Cancelled" : "Отменено",
     "Please add a title!" : "Пожалуйста добавьте заголовок!",
     "Please select a calendar!" : "Пожалуйста выберите календарь!",
+    "The event ends before it starts!" : "Окончание раньше начала!",
     "Global" : "Основные",
     "None" : "Отсутствует",
     "Every day" : "Каждый день",
@@ -85,8 +86,8 @@ OC.L10N.register(
     "Please enter a valid WebCal-URL" : "Пожалуйста, введите правильный адрес WebCal",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Серьезная ошибка в прокси webcal. Пожалуйста, обратитесь к администратору для получения дополнительной информации.",
     "Title of the Event" : "Название события",
-    "starts" : "начинается",
-    "ends" : "заканчивается",
+    "Starts" : "Начинается",
+    "Ends" : "Заканчивается",
     "All day Event" : "Событие на весь день",
     "Delete" : "Удалить",
     "Cancel" : "Отмена",
@@ -131,6 +132,8 @@ OC.L10N.register(
     "New Subscription" : "Новая подписка",
     "Go back" : "Назад",
     "Go forward" : "Вперед",
+    "Calendar does not exist" : "Календарь не существует",
+    "Maybe you got a wrong link or the calendar was unshared?" : "Вероятно, неверная ссылка или общий доступ к календарю был закрыт.",
     "Edit event" : "Редактировать событие",
     "Delete Event" : "Удалить событие",
     "Save Event" : "Сохранить событие",
@@ -158,15 +161,17 @@ OC.L10N.register(
     "New calendar" : "Новый календарь",
     "File is empty" : "Файл пуст",
     "Import scheduled" : "Импорт запланирован",
-    "Subscribe & embed" : "Подписаться и встроить",
+    "%s shared the calendar <strong>%s</strong> with you" : "%s поделился с вами календарём  <strong>%s</strong> ",
+    "Embed" : "Встроить",
+    "IFrame to integrate" : "Iframe для встраивания",
     "Publish URL" : "Опубликовать URL",
-    "Iframe to integrate" : "Iframe для встраивания",
     "Settings & import" : "Настройки и импорт",
     "Skip simple event editor" : "Не использовать простой редактор события",
     "Show week numbers" : "Показывать номера недель",
     "Import calendar" : "Импорт календаря",
     "No Calendars selected for import" : "Не выбраны календари для импорта",
     "Primary CalDAV address" : "Основной адрес синхронизации CalDAV",
-    "iOS/OS X CalDAV address" : "Адрес синхронизации iOS/OS X CalDAV"
+    "iOS/OS X CalDAV address" : "Адрес синхронизации iOS/OS X CalDAV",
+    "Subscribe" : "Подписаться"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
