@@ -85,8 +85,8 @@ OC.L10N.register(
     "Please enter a valid WebCal-URL" : "Ju lutemi, jepni një url të vlefshme WebCal-URL",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Gabim i rëndë në webcal proxy. Ju lutemi, kontaktoni administratorin për më shumë informacion.",
     "Title of the Event" : "Titulli i Veprimtarisë",
-    "starts" : "fillon",
-    "ends" : "mbaron",
+    "Starts" : "Fillim",
+    "Ends" : "Mbarim",
     "All day Event" : "Veprimtari Gjithëditore",
     "Delete" : "Fshije",
     "Cancel" : "Anuloje",
@@ -158,7 +158,6 @@ OC.L10N.register(
     "File is empty" : "Skedari është bosh",
     "Import scheduled" : "Importimi u planifikua",
     "Publish URL" : "Publiko URL",
-    "Iframe to integrate" : "Iframe për tu integruar",
     "Settings & import" : "Konfigurimet dhe importi",
     "Skip simple event editor" : "Anashkaloje përpunuesin e thjeshtë të veprimtarive",
     "Show week numbers" : "Shfaq numra javësh",
