@@ -38,6 +38,7 @@ OC.L10N.register(
     "Cancelled" : "Avbruten",
     "Please add a title!" : "Vänligen lägg till en titel!",
     "Please select a calendar!" : "Vänligen välj en kalender!",
+    "The event ends before it starts!" : "Händelsen slutar innan den börjar!?",
     "Global" : "Global",
     "None" : "Ingen",
     "Every day" : "Varje dag",
@@ -85,8 +86,8 @@ OC.L10N.register(
     "Please enter a valid WebCal-URL" : "Vänligen ange en giltig WebCal-URL",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Allvarligt fel i webcal proxy. Vänligen kontakta administratören för vidare information.",
     "Title of the Event" : "Rubrik för händelsen",
-    "starts" : "börjar",
-    "ends" : "slutar",
+    "Starts" : "Börjar",
+    "Ends" : "Slutar",
     "All day Event" : "Heldag",
     "Delete" : "Radera",
     "Cancel" : "Avbryt",
@@ -118,6 +119,7 @@ OC.L10N.register(
     "More" : "Mer",
     "Edit" : "Ändra",
     "Link" : "Länk",
+    "iCal link" : "iCal-länk",
     "Download" : "Ladda ned",
     "Share with users or groups" : "Dela med användare eller grupper",
     "can edit" : "kan redigera",
@@ -158,7 +160,6 @@ OC.L10N.register(
     "File is empty" : "Filen är tom",
     "Import scheduled" : "Import schemalagd",
     "Publish URL" : "Publicera URL",
-    "Iframe to integrate" : "Iframe att integrera ",
     "Settings & import" : "Inställningar & import",
     "Skip simple event editor" : "Använd inte den enkla händelse-redigeraren",
     "Show week numbers" : "Visa veckonummer",
