@@ -38,6 +38,7 @@ OC.L10N.register(
     "Cancelled" : "İptal edilmiş",
     "Please add a title!" : "Lütfen bir başlık yazın!",
     "Please select a calendar!" : "Lütfen bir takvim seçin!",
+    "The event ends before it starts!" : "Etkinliğin bitiş tarihi başlangıç tarihinden önce!",
     "Global" : "Genel",
     "None" : "Hiçbiri",
     "Every day" : "Her gün",
@@ -85,8 +86,8 @@ OC.L10N.register(
     "Please enter a valid WebCal-URL" : "Lütfen geçerli bir WebCal adresi yazın",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Webcal vekil sunucusunda ciddi bir sorun var. Lütfen ayrıntılı bilgi almak için yönetici ile görüşün.",
     "Title of the Event" : "Etkinlik Başlığı",
-    "starts" : "başlangıç",
-    "ends" : "bitiş",
+    "Starts" : "Başlangıç",
+    "Ends" : "Bitiş",
     "All day Event" : "Tüm günlük etkinlik",
     "Delete" : "Sil",
     "Cancel" : "İptal",
@@ -106,7 +107,7 @@ OC.L10N.register(
     "Cheers!" : "Görüşmek üzere",
     "We wanted to inform you that %s has published the calendar %s." : "Bu ileti %s tarafından %s takviminin yayınlandığını bildirmek üzere gönderilmiştir.",
     "Click on the link below to access it" : "Takvime eirşmek için aşağıdaki bağlantıya tıklayın",
-    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Bir yükleme akışı hatası nedeniyle takvim asset pipeline özelliğine destek veremiyor.",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Bir yükleme akışı sorunu nedeniyle takvim asset pipeline özelliğine destek veremiyor.",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Lütfen yöneticinizle görüşerek \"asset-pipeline.enabled\" ayarını devre dışı bırakmasını isteyin.",
     "Day" : "Gün",
     "Week" : "Hafta",
@@ -131,6 +132,8 @@ OC.L10N.register(
     "New Subscription" : "Abonelik Ekle",
     "Go back" : "Geri dön",
     "Go forward" : "İleri git",
+    "Calendar does not exist" : "Takvim bulunamadı",
+    "Maybe you got a wrong link or the calendar was unshared?" : "Bağlantınız yanlış ya da takvim paylaşılmamış olabilir mi?",
     "Edit event" : "Etkinliği düzenle",
     "Delete Event" : "Etkinliği Sil",
     "Save Event" : "Etkinliği Kaydet",
@@ -158,15 +161,17 @@ OC.L10N.register(
     "New calendar" : "Takvim ekle",
     "File is empty" : "Dosya boş",
     "Import scheduled" : "Alma işlemi zamanlandı",
-    "Subscribe & embed" : "Abone ol ve göm",
+    "%s shared the calendar <strong>%s</strong> with you" : "%s sizinle <strong>%s</strong> takvimini paylaştı",
+    "Embed" : "Göm",
+    "IFrame to integrate" : "Bütünleştirilecek IFrame",
     "Publish URL" : "Yayın adresi",
-    "Iframe to integrate" : "bütünleştirilecek Iframe",
     "Settings & import" : "Ayarlar ve Alma",
     "Skip simple event editor" : "Basit etkinlik düzenleyici atlansın",
     "Show week numbers" : "Hafta numaraları görüntülensin",
     "Import calendar" : "Takvimi al",
     "No Calendars selected for import" : "Alınacak bir takvim seçilmemiş",
     "Primary CalDAV address" : "Birincil CalDAV adresi",
-    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresi"
+    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresi",
+    "Subscribe" : "Abone Ol"
 },
 "nplurals=2; plural=(n > 1);");
