@@ -38,6 +38,7 @@ OC.L10N.register(
     "Cancelled" : "已取消",
     "Please add a title!" : "请添加一个标题。",
     "Please select a calendar!" : "请选择一个日历。",
+    "The event ends before it starts!" : "事件在开始前结束！",
     "Global" : "全局",
     "None" : "不提醒",
     "Every day" : "每天",
@@ -85,8 +86,8 @@ OC.L10N.register(
     "Please enter a valid WebCal-URL" : "请输入有效的WebCal地址",
     "Severe error in webcal proxy. Please contact administrator for more information." : "webcal代理中出现严重错误。 要获取更详细信息，请与管理员联系。",
     "Title of the Event" : "事件标题",
-    "starts" : "开始于",
-    "ends" : "结束于",
+    "Starts" : "开始于",
+    "Ends" : "结束于",
     "All day Event" : "全天事件",
     "Delete" : "删除",
     "Cancel" : "取消",
@@ -131,6 +132,8 @@ OC.L10N.register(
     "New Subscription" : "新的订阅",
     "Go back" : "回到上一步",
     "Go forward" : "向前",
+    "Calendar does not exist" : "日历不存在",
+    "Maybe you got a wrong link or the calendar was unshared?" : "也许你访问了错误的连接或者此日历未被分享？",
     "Edit event" : "编辑事件",
     "Delete Event" : "删除事件",
     "Save Event" : "保存事件",
@@ -158,15 +161,17 @@ OC.L10N.register(
     "New calendar" : "新建日历",
     "File is empty" : "文件是空的",
     "Import scheduled" : "导入时间表",
-    "Subscribe & embed" : "订阅 & 嵌入",
+    "%s shared the calendar <strong>%s</strong> with you" : "%s给你分享了日历 <strong>%s</strong>",
+    "Embed" : "嵌入",
+    "IFrame to integrate" : "一体化框架",
     "Publish URL" : "发布 URL",
-    "Iframe to integrate" : "使用Iframe框架嵌入",
     "Settings & import" : "设置 & 导入",
     "Skip simple event editor" : "跳过简单事件编辑器",
     "Show week numbers" : "显示周次",
     "Import calendar" : "导入日历",
     "No Calendars selected for import" : "未选择要导入的日历",
     "Primary CalDAV address" : "主要的 CalDAV 地址",
-    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV 地址"
+    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV 地址",
+    "Subscribe" : "订阅"
 },
 "nplurals=1; plural=0;");
