@@ -65,8 +65,6 @@ OC.L10N.register(
     "{type} at {time}" : "{type} 在 {time}",
     "{calendar} shared by {owner}" : "{calendar} 由 {owner} 分享",
     "Title of the Event" : "活動標題",
-    "starts" : "開始",
-    "ends" : "結束",
     "All day Event" : "全天活動",
     "Delete" : "刪除",
     "Cancel" : "取消",
@@ -120,7 +118,6 @@ OC.L10N.register(
     "The file contains objects incompatible with the selected calendar" : "這個檔案包含與選取的日曆不相容的物件",
     "New calendar" : "新日曆",
     "Import scheduled" : "已排程匯入",
-    "Settings" : "設定",
     "Import calendar" : "匯入日曆",
     "No Calendars selected for import" : "沒有選擇要匯入的日曆",
     "Primary CalDAV address" : "主要的 CalDAV 地址",
